==> nextcloud-18.0.4.tgz: nextcloud/apps/privacy/l10n/zh_CN.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "隐私",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "隐私中心为您显示您数据的存放位置以及谁能访问这些数据，这可能是因为您将数据共享给了他们或者他们是管理员。",
    "Remove external admin" : "移除外部管理员",
    "Add external admin" : "添加外部管理员",
    "Your files are not protected by encryption." : "您的文件没有进行加密保护。",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "您的文件由 {linkopen}服务器端加密机制 ↗{linkclose} 进行加密。",
    "This server is protected with full-disk-encryption." : "此服务器被全盘加密保护。",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "您的文件由 {linkopen}服务器端加密机制 ↗{linkclose} 进行加密。同时，此服务器被全盘加密保护。",
    "This server is using full-disk-encryption." : "此服务器正在使用全盘加密。",
    "Change data location" : "修改数据位置",
    "Your data is located in: " : "您的数据位于：",
    "The admin hasn't selected the location of the server yet." : "管理员尚未选定此服务器所在的地区。",
    "Please select a country" : "请选择一个国家",
    "You don't have any shares with individual users." : "您没有与任何个人用户的共享。",
    "Somaliland" : "索马里兰",
    "United Arab Emirates" : "阿拉伯联合酋长国",
    "Afghanistan" : "阿富汗",
    "Albania" : "阿尔巴尼亚",
    "Armenia" : "亚美尼亚共和国",
    "Angola" : "安哥拉",
    "Argentina" : "阿根廷",
    "Austria" : "奥地利",
    "Australia" : "澳大利亚",
    "Azerbaijan" : "阿塞拜疆",
    "Bosnia and Herzegowina" : "波黑",
    "Bangladesh" : "孟加拉国",
    "Belgium" : "比利时",
    "Burkina Faso" : "布基纳法索",
    "Bulgaria" : "保加利亚",
    "Burundi" : "布隆迪",
    "Benin" : "贝宁",
    "Brunei" : "文莱",
    "Bolivia" : "玻利维亚",
    "Brazil" : "巴西",
    "Bahamas" : "巴哈马",
    "Bhutan" : "不丹",
    "Botswana" : "博茨瓦纳",
    "Belarus" : "白俄罗斯",
    "Belize" : "伯利兹",
    "Canada" : "加拿大",
    "Democratic Republic of the Congo" : "刚果民主共和国",
    "Central African Republic" : "中非共和国",
    "Congo" : "刚果",
    "Switzerland" : "瑞士",
    "Cote d'Ivoire" : "科特迪瓦",
    "Chile" : "智利",
    "Cameroon" : "喀麦隆",
    "China" : "中国",
    "Colombia" : "哥伦比亚",
    "Costa Rica" : "哥斯达黎加",
    "Cuba" : "古巴",
    "Cyprus" : "塞浦路斯",
    "Czech" : "捷克",
    "Germany" : "德国",
    "Djibouti" : "吉布提",
    "Denmark" : "丹麦",
    "Dominican Republic" : "多米尼加共和国",
    "Algeria" : "阿尔及利亚",
    "Ecuador" : "厄瓜多尔",
    "Estonia" : "爱沙尼亚",
    "Egypt" : "埃及",
    "West Sahara" : "西撒哈拉",
    "Eritrea" : "厄立特里亚",
    "Spain" : "西班牙",
    "Ethiopia" : "埃塞俄比亚",
    "Finland" : "芬兰",
    "Fiji" : "斐济",
    "Falkland Islands" : "福克兰群岛",
    "France" : "法国",
    "Gabon" : "加蓬",
    "United Kingdom" : "英国",
    "Georgia" : "格鲁吉亚",
    "Ghana" : "加纳",
    "Greenland" : "格陵兰",
    "Gambia" : "冈比亚",
    "Guinea" : "几内亚",
    "Equatorial Guinea" : "赤道几内亚",
    "Greece" : "希腊",
    "Guatemala" : "危地马拉",
    "Guinea-Bissau" : "几内亚比绍",
    "Guyana" : "圭亚那",
    "Honduras" : "洪都拉斯",
    "Croatia" : "克罗地亚",
    "Haiti" : "海地",
    "Hungary" : "匈牙利",
    "Indonesia" : "印度尼西亚",
    "Ireland" : "爱尔兰",
    "Israel" : "以色列",
    "India" : "印度",
    "Iraq" : "伊拉克",
    "Iran" : "伊朗",
    "Iceland" : "冰岛",
    "Italy" : "意大利",
    "Jamaica" : "牙买加",
    "Jordan" : "约旦",
    "Japan" : "日本",
    "Kenya" : "肯尼亚",
    "Kyrgyzstan" : "吉尔吉斯斯坦",
    "Cambodia" : "柬埔寨",
    "North Korea" : "北朝鲜",
    "South Korea" : "南朝鲜",
    "Kuwait" : "科威特",
    "Kazakhstan" : "哈萨克斯坦",
    "Laos" : "老挝",
    "Lebanon" : "黎巴嫩",
    "Sri Lanka" : "斯里兰卡",
    "Liberia" : "利比里亚",
    "Lesotho" : "莱索托",
    "Lithuania" : "立陶宛",
    "Luxembourg" : "卢森堡",
    "Latvia" : "拉脱维亚",
    "Libya" : "利比亚",
    "Morocco" : "摩洛哥",
    "Moldova" : "摩尔多瓦",
    "Montenegro" : "黑山",
    "Madagascar" : "马达加斯加",
    "Macedonia" : "马其顿",
    "Mali" : "马里",
    "Myanmar" : "缅甸",
    "Mongolia" : "蒙古",
    "Mauritania" : "毛里塔尼亚",
    "Malawi" : "马拉维",
    "Mexico" : "墨西哥",
    "Malaysia" : "马来西亚",
    "Mozambique" : "莫桑比克",
    "Namibia" : "纳米比亚",
    "New Caledonia" : "新喀里多尼亚",
    "Niger" : "尼日尔",
    "Nigeria" : "尼日利亚",
    "Nicaragua" : "尼加拉瓜",
    "Netherlands" : "荷兰",
    "Norway" : "挪威",
    "Nepal" : "尼泊尔",
    "New Zealand" : "新西兰",
    "Oman" : "阿曼",
    "Panama" : "巴拿马",
    "Peru" : "秘鲁",
    "Papua New Guinea" : "巴布亚新几内亚",
    "Philippines" : "菲律宾",
    "Pakistan" : "巴基斯坦",
    "Poland" : "波兰",
    "Puerto Rico" : "波多黎各",
    "Portugal" : "葡萄牙",
    "Paraguay" : "巴拉圭",
    "Qatar" : "卡塔尔",
    "Romania" : "罗马尼亚",
    "Serbia" : "塞尔维亚",
    "Russia" : "俄罗斯",
    "Rwanda" : "卢旺达",
    "Saudi Arabia" : "沙特阿拉伯",
    "Solomon Islands" : "所罗门群岛",
    "Sudan" : "苏丹",
    "Sweden" : "瑞典",
    "Singapore" : "新加坡",
    "Slovenia" : "斯洛文尼亚",
    "Slovakia" : "斯洛伐克",
    "Sierra Leone" : "塞拉利昂",
    "Senegal" : "塞内加尔",
    "Somalia" : "索马里",
    "Suriname" : "苏里南",
    "South Sudan" : "南苏丹",
    "El Salvador" : "萨尔瓦多",
    "Syria" : "叙利亚",
    "Swaziland" : " 斯威士兰",
    "Chad" : " 乍得",
    "Fr. S. Antarctic Lands" : "法属南极地区",
    "Togo" : "多哥",
    "Thailand" : "泰国",
    "Tajikistan" : "塔吉克斯坦",
    "Timor-Leste" : "东帝汶",
    "Turkmenistan" : "土库曼斯坦",
    "Tunisia" : "突尼斯",
    "Turkey" : "土耳其",
    "Trinidad and Tobago" : "特立尼达和多巴哥",
    "Taiwan" : "台湾",
    "Tanzania" : "坦桑尼亚",
    "Ukraine" : "乌克兰",
    "Uganda" : "乌干达",
    "United States" : "美国",
    "Uruguay" : "乌拉圭",
    "Uzbekistan" : "乌兹别克斯坦",
    "Venezuela" : "委内瑞拉",
    "Vietnam" : "越南",
    "Vanuatu" : "瓦努阿图",
    "Yemen" : "也门",
    "South Africa" : "南非",
    "Zambia" : "赞比亚",
    "Zimbabwe" : "津巴布韦",
    "Your Nextcloud account" : "您的Nextcloud账号",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "您的数据代表您自己，可以很容易地被滥用。我们Nextcloud团队相信您有权决定如何处理您的数据。Nextcloud将像用户数据宣言中的规定那样来保护您的权利！",
    "User Data Manifesto 2.0" : "用户数据宣言 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "定义互联网时代用户对自己数据的基本权利",
    "Control" : "控制",
    "over user data access" : "对用户数据的访问",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "由用户明确自愿上传的数据最终应由用户控制。用户应当能够决定允许谁能够直接访问他们的数据，以及在何种权限和许可下允许访问。",
    "Knowledge" : "知情权",
    "of how the data is stored" : "关于数据如何存储",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "当数据被上传到特定的服务提供商，用户应当被告知服务商存储数据的位置、保留数据的时间、服务商如何管理数据以适用哪些法律。",
    "Freedom" : "自由权",
    "to choose a platform" : "去选择任何平台",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "用户应总是能够随时从服务中提取数据而不会遭受任何厂商锁定。有必要使用开放标准的格式和协议来确保达到这一目标。",
    "Learn more ↗" : "了解更多",
    "Where is your data?" : "您的数据在哪里？",
    "Who has access to your data?" : "谁可以访问您的数据？",
    "Administrators" : "管理员",
    "People you shared with" : "与您共享的人",
    "Privacy policy" : "隐私政策",
    "Read the privacy policy." : "阅读隐私政策。",
    "Encryption" : "加密"
},
"nplurals=1; plural=0;");

==> nextcloud-18.0.8.tgz: nextcloud/apps/privacy/l10n/zh_CN.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "隐私",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "隐私中心为您显示您数据的存放位置以及谁能访问这些数据，这可能是因为您将数据共享给了他们或者他们是管理员。",
    "Remove external admin" : "移除外部管理员",
    "Add external admin" : "添加外部管理员",
    "This server is using full-disk-encryption." : "此服务器正在使用全盘加密。",
    "Your files are not protected by encryption." : "您的文件没有进行加密保护。",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "您的文件由 {linkopen}服务器端加密机制 ↗{linkclose} 进行加密。",
    "This server is protected with full-disk-encryption." : "此服务器被全盘加密保护。",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "您的文件由 {linkopen}服务器端加密机制 ↗{linkclose} 进行加密。同时，此服务器被全盘加密保护。",
    "Your data is located in: " : "您的数据位于：",
    "The admin hasn't selected the location of the server yet." : "管理员尚未选定此服务器所在的地区。",
    "Change data location" : "修改数据位置",
    "You don't have any shares with individual users." : "您没有与任何个人用户的共享。",
    "Somaliland" : "索马里兰",
    "Andorra" : "安道尔",
    "United Arab Emirates" : "阿拉伯联合酋长国",
    "Afghanistan" : "阿富汗",
    "Antigua and Barbuda" : "安提瓜和巴布达",
    "Anguilla" : "安圭拉",
    "Albania" : "阿尔巴尼亚",
    "Armenia" : "亚美尼亚共和国",
    "Angola" : "安哥拉",
    "Antarctica" : "南极洲",
    "Argentina" : "阿根廷",
    "American Samoa" : "美属萨摩亚",
    "Austria" : "奥地利",
    "Australia" : "澳大利亚",
    "Aruba" : "阿鲁巴",
    "Åland Islands" : "奥兰",
    "Azerbaijan" : "阿塞拜疆",
    "Bosnia and Herzegovina" : "波斯尼亚和黑塞哥维那",
    "Barbados" : "巴巴多斯",
    "Bangladesh" : "孟加拉国",
    "Belgium" : "比利时",
    "Burkina Faso" : "布基纳法索",
    "Bulgaria" : "保加利亚",
    "Bahrain" : "巴林",
    "Burundi" : "布隆迪",
    "Benin" : "贝宁",
    "Saint Barthélemy" : "圣巴泰勒米",
    "Bermuda" : "百慕大",
    "Brunei" : "文莱",
    "Bolivia" : "玻利维亚",
    "Bonaire, Sint Eustatius and Saba" : "博内尔岛，圣尤斯特歇斯岛和萨巴岛",
    "Brazil" : "巴西",
    "Bahamas" : "巴哈马",
    "Bhutan" : "不丹",
    "Bouvet Island" : "布维岛",
    "Botswana" : "博茨瓦纳",
    "Belarus" : "白俄罗斯",
    "Belize" : "伯利兹",
    "Canada" : "加拿大",
    "Cocos (Keeling) Islands" : "科科斯（基林）群岛",
    "Democratic Republic of the Congo" : "刚果民主共和国",
    "Central African Republic" : "中非共和国",
    "Congo" : "刚果",
    "Switzerland" : "瑞士",
    "Cote d'Ivoire" : "科特迪瓦",
    "Cook Islands" : "库克群岛",
    "Chile" : "智利",
    "Cameroon" : "喀麦隆",
    "China" : "中国",
    "Colombia" : "哥伦比亚",
    "Costa Rica" : "哥斯达黎加",
    "Cuba" : "古巴",
    "Cabo Verde" : "佛得角",
    "Curaçao" : "库拉索",
    "Christmas Island" : "圣诞岛",
    "Cyprus" : "塞浦路斯",
    "Czech" : "捷克",
    "Germany" : "德国",
    "Djibouti" : "吉布提",
    "Denmark" : "丹麦",
    "Dominican Republic" : "多米尼加共和国",
    "Algeria" : "阿尔及利亚",
    "Ecuador" : "厄瓜多尔",
    "Estonia" : "爱沙尼亚",
    "Egypt" : "埃及",
    "West Sahara" : "西撒哈拉",
    "Eritrea" : "厄立特里亚",
    "Spain" : "西班牙",
    "Ethiopia" : "埃塞俄比亚",
    "Finland" : "芬兰",
    "Fiji" : "斐济",
    "Falkland Islands" : "福克兰群岛",
    "Faroe Islands" : "法罗群岛",
    "France" : "法国",
    "Gabon" : "加蓬",
    "United Kingdom" : "英国",
    "Grenada" : "格林纳达",
    "Georgia" : "格鲁吉亚",
    "French Guiana" : "法属圭亚那",
    "Guernsey" : "根西岛",
    "Ghana" : "加纳",
    "Gibraltar" : "直布罗陀",
    "Greenland" : "格陵兰",
    "Gambia" : "冈比亚",
    "Guinea" : "几内亚",
    "Guadeloupe" : "瓜德罗普岛",
    "Equatorial Guinea" : "赤道几内亚",
    "Greece" : "希腊",
    "South Georgia and the South Sandwich Islands" : "南乔治亚岛和南桑威奇群岛",
    "Guatemala" : "危地马拉",
    "Guam" : "关岛",
    "Guinea-Bissau" : "几内亚比绍",
    "Guyana" : "圭亚那",
    "Honduras" : "洪都拉斯",
    "Hong Kong" : "香港",
    "Heard Island and McDonald Islands" : "赫德岛和麦当劳群岛",
    "Croatia" : "克罗地亚",
    "Haiti" : "海地",
    "Hungary" : "匈牙利",
    "Indonesia" : "印度尼西亚",
    "Ireland" : "爱尔兰",
    "Israel" : "以色列",
    "Isle of Man" : "马恩岛",
    "India" : "印度",
    "British Indian Ocean Territory" : "英属印度洋领地",
    "Iraq" : "伊拉克",
    "Iran" : "伊朗",
    "Iceland" : "冰岛",
    "Italy" : "意大利",
    "Jamaica" : "牙买加",
    "Jordan" : "约旦",
    "Japan" : "日本",
    "Kenya" : "肯尼亚",
    "Kyrgyzstan" : "吉尔吉斯斯坦",
    "Cambodia" : "柬埔寨",
    "Kiribati" : "基里巴斯",
    "Saint Kitts and Nevis" : "圣基茨和尼维斯",
    "North Korea" : "北朝鲜",
    "South Korea" : "南朝鲜",
    "Kuwait" : "科威特",
    "Cayman Islands" : "开曼群岛",
    "Kazakhstan" : "哈萨克斯坦",
    "Laos" : "老挝",
    "Lebanon" : "黎巴嫩",
    "Saint Lucia" : "圣卢西亚",
    "Liechtenstein" : "列支敦士登",
    "Sri Lanka" : "斯里兰卡",
    "Liberia" : "利比里亚",
    "Lesotho" : "莱索托",
    "Lithuania" : "立陶宛",
    "Luxembourg" : "卢森堡",
    "Latvia" : "拉脱维亚",
    "Libya" : "利比亚",
    "Morocco" : "摩洛哥",
    "Monaco" : "摩纳哥",
    "Moldova" : "摩尔多瓦",
    "Montenegro" : "黑山",
    "Madagascar" : "马达加斯加",
    "Marshall Islands" : "马绍尔群岛",
    "Macedonia" : "马其顿",
    "Mali" : "马里",
    "Myanmar" : "缅甸",
    "Mongolia" : "蒙古",
    "Macao" : "澳门",
    "Northern Mariana Islands" : "北马里亚纳群岛",
    "Mauritania" : "毛里塔尼亚",
    "Montserrat" : "蒙特塞拉特",
    "Malta" : "马耳他",
    "Mauritius" : "毛里求斯",
    "Maldives" : "马尔代夫",
    "Malawi" : "马拉维",
    "Mexico" : "墨西哥",
    "Malaysia" : "马来西亚",
    "Mozambique" : "莫桑比克",
    "Namibia" : "纳米比亚",
    "New Caledonia" : "新喀里多尼亚",
    "Niger" : "尼日尔",
    "Norfolk Island" : "诺福克岛",
    "Nigeria" : "尼日利亚",
    "Nicaragua" : "尼加拉瓜",
    "Netherlands" : "荷兰",
    "Norway" : "挪威",
    "Nepal" : "尼泊尔",
    "Nauru" : "瑙鲁",
    "Niue" : "纽埃",
    "New Zealand" : "新西兰",
    "Oman" : "阿曼",
    "Panama" : "巴拿马",
    "Peru" : "秘鲁",
    "French Polynesia" : "法属波利尼西亚",
    "Papua New Guinea" : "巴布亚新几内亚",
    "Philippines" : "菲律宾",
    "Pakistan" : "巴基斯坦",
    "Poland" : "波兰",
    "Saint Pierre and Miquelon" : "圣皮埃尔和密克隆",
    "Pitcairn" : "皮特凯恩",
    "Puerto Rico" : "波多黎各",
    "Portugal" : "葡萄牙",
    "Palau" : "帕劳",
    "Paraguay" : "巴拉圭",
    "Qatar" : "卡塔尔",
    "Réunion" : "留尼汪",
    "Romania" : "罗马尼亚",
    "Serbia" : "塞尔维亚",
    "Russia" : "俄罗斯",
    "Rwanda" : "卢旺达",
    "Saudi Arabia" : "沙特阿拉伯",
    "Solomon Islands" : "所罗门群岛",
    "Seychelles" : "塞舌尔",
    "Sudan" : "苏丹",
    "Sweden" : "瑞典",
    "Singapore" : "新加坡",
    "Saint Helena, Ascension and Tristan da Cunha" : "圣赫勒拿，阿森松岛和特里斯坦达库尼亚",
    "Slovenia" : "斯洛文尼亚",
    "Svalbard and Jan Mayen" : "斯瓦尔巴和扬马延",
    "Slovakia" : "斯洛伐克",
    "Sierra Leone" : "塞拉利昂",
    "San Marino" : "圣马力诺",
    "Senegal" : "塞内加尔",
    "Somalia" : "索马里",
    "Suriname" : "苏里南",
    "South Sudan" : "南苏丹",
    "Sao Tome and Principe" : "圣多美和普林西比",
    "El Salvador" : "萨尔瓦多",
    "Syria" : "叙利亚",
    "Swaziland" : " 斯威士兰",
    "Turks and Caicos Islands" : "特克斯和凯科斯群岛",
    "Chad" : " 乍得",
    "Fr. S. Antarctic Lands" : "法属南极地区",
    "Togo" : "多哥",
    "Thailand" : "泰国",
    "Tajikistan" : "塔吉克斯坦",
    "Tokelau" : "托克劳",
    "Timor-Leste" : "东帝汶",
    "Turkmenistan" : "土库曼斯坦",
    "Tunisia" : "突尼斯",
    "Tonga" : "汤加",
    "Turkey" : "土耳其",
    "Trinidad and Tobago" : "特立尼达和多巴哥",
    "Tuvalu" : "图瓦卢",
    "Taiwan" : "台湾",
    "Tanzania" : "坦桑尼亚",
    "Ukraine" : "乌克兰",
    "Uganda" : "乌干达",
    "United States Minor Outlying Islands" : "美国本土外小岛屿",
    "United States" : "美国",
    "Uruguay" : "乌拉圭",
    "Uzbekistan" : "乌兹别克斯坦",
    "Holy See" : "教廷",
    "Saint Vincent and the Grenadines" : "圣文森特和格林纳丁斯",
    "Venezuela" : "委内瑞拉",
    "Virgin Islands (British)" : "维尔京群岛（英国）",
    "Virgin Islands (U.S.)" : "维尔京群岛（美国）",
    "Vietnam" : "越南",
    "Vanuatu" : "瓦努阿图",
    "Wallis and Futuna" : "瓦利斯和富图纳群岛",
    "Samoa" : "萨摩亚",
    "Yemen" : "也门",
    "Mayotte" : "马约特",
    "South Africa" : "南非",
    "Zambia" : "赞比亚",
    "Zimbabwe" : "津巴布韦",
    "Your Nextcloud account" : "您的 Nextcloud 账号",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "您的数据代表您自己，可以很容易地被滥用。我们Nextcloud团队相信您有权决定如何处理您的数据。Nextcloud将像用户数据宣言中的规定那样来保护您的权利！",
    "User Data Manifesto 2.0" : "用户数据宣言 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "定义互联网时代用户对自己数据的基本权利",
    "Control" : "控制",
    "over user data access" : "对用户数据的访问",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "由用户明确自愿上传的数据最终应由用户控制。用户应当能够决定允许谁能够直接访问他们的数据，以及在何种权限和许可下允许访问。",
    "Knowledge" : "知情权",
    "of how the data is stored" : "关于数据如何存储",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "当数据被上传到特定的服务提供商，用户应当被告知服务商存储数据的位置、保留数据的时间、服务商如何管理数据以适用哪些法律。",
    "Freedom" : "自由权",
    "to choose a platform" : "去选择任何平台",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "用户应总是能够随时从服务中提取数据而不会遭受任何厂商锁定。有必要使用开放标准的格式和协议来确保达到这一目标。",
    "Learn more ↗" : "了解更多",
    "Where is your data?" : "您的数据在哪里？",
    "Who has access to your data?" : "谁可以访问您的数据？",
    "Administrators" : "管理员",
    "People you shared with" : "与您共享的人",
    "Privacy policy" : "隐私政策",
    "Read the privacy policy." : "阅读隐私政策。",
    "Encryption" : "加密",
    "Please select a country" : "请选择一个国家",
    "Bosnia and Herzegowina" : "波黑"
},
"nplurals=1; plural=0;");
